# Step-by-step tutorials

## Setup

For installing Sockeye follow the [installation instructions](setup.html) to manually install Sockeye and all dependencies.
The tutorials below might have additional dependencies that will be mentioned at the beginning of each tutorial.

## Tutorials

Below is the full list of tutorials we provide. We recommend going through them in order as they will gradually
introduce different concepts and parameters used for training and translation.

1. [Sequence copy task](tutorials/seqcopy.html)
1. [WMT German to English news translation](tutorials/wmt.html)
1. [Domain adaptation of NMT models](tutorials/adapt.html)
1. [Large data: WMT German-English 2018](tutorials/wmt_large.html)
1. [Multilingual Zero-shot Translation IWSLT 2017](tutorials/multilingual.html)